@@ -43,23 +43,4 @@ class ClassicGenActor(ClassicActor):
         await assign_handler.pass_done()
 
 
-class ClassicThreadedFuncActor(ClassicActor):
-    nworkers = 5
 
-    def __init__(self, *args, **kwargs) -> None:
-        super().__init__(*args, **kwargs)
-        self.threadpool = ThreadPoolExecutor(self.nworkers)
-
-    def progress(self, value, percentage):
-        if self.loop.is_running():
-            future = asyncio.run_coroutine_threadsafe(self._progress(value, percentage=percentage), self.loop)
-            return future.result()
-        else:
-            self.loop.run_until_complete(self._progress(value, percentage=percentage))
-
-    def assign(self, assign_handler: AssignHandler, reserve_handler: ReserveHandler, args,kwargs):
-        raise NotImplementedError("")   
-
-    async def _assign(self, assign_handler: AssignHandler, reserve_handler: ReserveHandler, args, kwargs):
-        result = await self.loop.run_in_executor(self.threadpool, self.assign, assign_handler, reserve_handler, args, kwargs)
-        await assign_handler.pass_return(result)
