@@ -48,11 +48,14 @@ class FunctionalGenActor(FunctionalActor):
         reserve_handler_context.set(reserve_handler)
         provide_handler_context.set(self.provide_handler)
 
-        async for result in self.assign(*args, **kwargs):
-            lastresult = await shrinkOutputs(self.template.node, result) if self.shrinkOutputs else result
-            await assign_handler.pass_yield(lastresult)
+        try:
+            async for result in self.assign(*args, **kwargs):
+                lastresult = await shrinkOutputs(self.template.node, result) if self.shrinkOutputs else result
+                await assign_handler.pass_yield(lastresult)
 
-        await assign_handler.pass_done()
+            await assign_handler.pass_done()
+        except Exception as e:
+            await assign_handler.pass_exception(e)
 
 
 class FunctionalThreadedFuncActor(FunctionalActor):
@@ -65,10 +68,19 @@ class FunctionalThreadedFuncActor(FunctionalActor):
     def assign(self, *args, **kwargs):
         raise NotImplementedError("")   
 
-    async def _assign(self, assign_handler: AssignHandler, reserve_handler: ReserveHandler, args, kwargs):
+
+    def _assign_threaded(self, args, kwargs, loop, assign_handler, reserve_handler):
         assign_handler_context.set(assign_handler)
         reserve_handler_context.set(reserve_handler)
-        provide_handler_context.set(self.provide_handler)
+        loop_context.set(loop)
+        res = self.assign(*args, **kwargs)
+        loop_context.set(None)
+        return res
 
-        result = await self.loop.run_in_executor(self.threadpool, self.assign, *args, **kwargs)
-        await assign_handler.pass_return(result)
\ No newline at end of file
+    async def _assign(self, assign_handler: AssignHandler, reserve_handler: ReserveHandler, args, kwargs):
+        try:
+            result = await self.loop.run_in_executor(self.threadpool, self._assign_threaded, args, kwargs, self.loop, assign_handler, reserve_handler)
+            shrinked_returns = await shrinkOutputs(self.template.node, result) if self.shrinkOutputs else result
+            await assign_handler.pass_result(shrinked_returns)
+        except Exception as e:
+            await assign_handler.pass_exception(e)
\ No newline at end of file
