@@ -176,8 +176,8 @@ class ArnheimModel(BaseModel, metaclass=ArnheimModelMeta):
         except Exception as e:
             raise ArnheimModelConfigurationError(f"Make soure your Model {cls.__name__}overwrites Meta identifier: {e}")
 
-        from bergen.registries.client import get_current_client
-        return get_current_client().getWardForIdentifier(identifier=identifier)
+        from bergen.registries.ward import get_ward_registry
+        return get_ward_registry().getWardForIdentifier(identifier=identifier)
 
     @classmethod
     def getMeta(cls):
